pub fn init_test_logging()Expand description
Initialize logging for tests.
This uses a test-friendly configuration and ignores errors from multiple initializations (common in tests).
pub fn init_test_logging()Initialize logging for tests.
This uses a test-friendly configuration and ignores errors from multiple initializations (common in tests).