pub struct CapabilitySet { /* private fields */ }Expand description
A set of capabilities supported by a device or protocol.
Implementations
Sourceimpl CapabilitySet
impl CapabilitySet
Sourcepub fn new() -> CapabilitySet
pub fn new() -> CapabilitySet
Create an empty capability set.
Sourcepub fn with_capabilities(
caps: impl IntoIterator<Item = Capability>,
) -> CapabilitySet
pub fn with_capabilities( caps: impl IntoIterator<Item = Capability>, ) -> CapabilitySet
Create a capability set with the given capabilities.
Sourcepub fn add(&mut self, cap: Capability)
pub fn add(&mut self, cap: Capability)
Add a capability.
Sourcepub fn remove(&mut self, cap: Capability)
pub fn remove(&mut self, cap: Capability)
Remove a capability.
Sourcepub fn supports(&self, cap: Capability) -> bool
pub fn supports(&self, cap: Capability) -> bool
Check if a capability is supported.
Sourcepub fn supports_all(&self, caps: &[Capability]) -> bool
pub fn supports_all(&self, caps: &[Capability]) -> bool
Check if all given capabilities are supported.
Sourcepub fn supports_any(&self, caps: &[Capability]) -> bool
pub fn supports_any(&self, caps: &[Capability]) -> bool
Check if any of the given capabilities are supported.
Sourcepub fn list(&self) -> impl Iterator<Item = Capability>
pub fn list(&self) -> impl Iterator<Item = Capability>
List all supported capabilities.
Sourcepub fn merge(&mut self, other: &CapabilitySet)
pub fn merge(&mut self, other: &CapabilitySet)
Merge with another capability set.
Sourcepub fn intersection(&self, other: &CapabilitySet) -> CapabilitySet
pub fn intersection(&self, other: &CapabilitySet) -> CapabilitySet
Create the intersection of two capability sets.