Reusable CLI argument validators.
Provides value_parser compatible functions for clap argument validation.
Each validator returns Result<T, String> as required by clap.
Functions
- parse_
nonzero_ count - Validates that a count value is at least 1.
- parse_
port - Validates that a port number is within the usable range (1–65535).